@@ -2,81 +2,64 @@
 context help system for your kivy apps
 ======================================
 
-This namespace portion is a requirement
-of the :mod:`ae.kivy_app` module and is
-tight coupled to it.
+The mixin class :class:`HelpBehavior` provided by this namespace portion is extending and preparing any Kivy widget for
+to show an individual help text for it. The widget :class:`HelpToggler` is a toggle button to switch the help mode
+on and off. Finally the widget :class:`HelpLayout` of this portion displays the translatable help texts within your app.
 
-For to keep the module size small it got
-extracted into its own namespace portion.
+This namespace portion is a requirement of the :mod:`ae.kivy_app` module and is tight coupled to it. To keep the
+module size small it got extracted into its own namespace portion.
 
-:mod:`ae.kivy_app` is automatically
-importing/integrating this module for you.
-For android apps built with buildozer you
-only need to add it to the requirements
-list in your `buildozer.spec` file.
+:mod:`ae.kivy_app` is automatically importing/integrating this module for you. For android apps built with buildozer you
+only need to add it to the requirements list in your `buildozer.spec` file.
 
 
 help behaviour mixin
 --------------------
 
-The mixin class :class:`HelpBehavior`
-of this namespace portion is extending
-and preparing any Kivy widget for to
-show an individual help text for it.
+To show a i18n translatable help text for a Kivy widget create either a sub-class of the widget. The following example
+allows to attach a help text to a Kivy :class:`~kivy.uix.button.Button`::
+
+    from kivy.uix.button import Button
+    from ae.kivy_help import HelpBehavior
+
+    class ButtonWithHelpText(HelpBehavior, Button):
+        ...
+
+Alternatively you can archive this via a kv-lang rule::
+
+    <ButtonWithHelpText@HelpBehavior+Button>
+
 
 .. note::
-    For to automatically lock and mark the
-    widget you want to add help texts for,
-    this mixin class has to be specified as
-    the first class in the list of classes
-    your widget get inherited from.
+    To automatically lock and mark the widget you want to add help texts for, this mixin class has to be specified
+    as the first class in the list of classes your widget get inherited from.
 
-The correct identification of each
-help-aware widget presuppose that the
-attribute :attr:`~HelpBehavior.help_id`
-has a unique value for each widget
-instance. This is done automatically for
-the widgets provided by the
-module :mod:`~ae.kivy_app` for to change
-the app flow or app states (like e.g.
-:class:`~ae.kivy_app.FlowButton`).
+The correct identification of each help-aware widget presuppose that the attribute :attr:`~HelpBehavior.help_id` has a
+unique value for each widget instance. This is done automatically for the widgets provided by the module
+:mod:`~ae.kivy_app` to change the app flow or app states (like e.g. :class:`~ae.kivy_app.FlowButton`).
 
-The :attr:`~HelpBehavior.help_vars`
-is a dict which can be used to provide extra
-context data for the generation and the
-display of help texts.
+The :attr:`~HelpBehavior.help_vars` is a dict which can be used to provide extra context data to dynamically generate,
+translate and display individual help texts.
 
 
 help activation and de-activation
 ---------------------------------
 
-Use the widget :class:`HelpToggler`
-provided by this namespace portion
-in your app for to toggle the
-active state of the help mode.
+Use the widget :class:`HelpToggler` provided by this namespace portion in your app to toggle the active state of the
+help mode.
 
 .. hint::
-    The :class:`HelpToggler` is using
-    the low-level touch events to
-    prevent the dispatch of the Kivy
-    events `on_press`, `on_release`
-    and `on_dismiss` for to allow
-    to show help texts for opened
-    dropdowns and popups.
+    The :class:`HelpToggler` is using the low-level touch events to prevent the dispatch of the Kivy events `on_press`,
+    `on_release` and `on_dismiss` to allow to show help texts for opened dropdowns and popups.
 
 
-layout widget for to display help text
---------------------------------------
-
-The layout widget :class:`HelpLayout`
-of this module is displaying the help
-texts prepared by the method
-:meth:`~ae.gui_help.HelpAppBase.help_display`
-of the namespace portion :mod:`ae.gui_help`.
-
+layout widget to display help text
+----------------------------------
 
+The layout widget :class:`HelpLayout` of this module is displaying the help texts prepared by the method
+:meth:`~ae.gui_help.HelpAppBase.help_display` of the namespace portion :mod:`ae.gui_help`.
 """
-from typing import Callable, cast
+from typing import Callable
 
 from kivy.input import MotionEvent                                                          # type: ignore
 from kivy.lang import Builder                                                               # type: ignore
@@ -86,12 +69,10 @@ from kivy.uix.image import Image
 from kivy.uix.scrollview import ScrollView                                                  # type: ignore
 from kivy.app import App                                                                    # type: ignore
 
-from ae.core import main_app_instance                                                       # type: ignore
-from ae.gui_help import HelpAppBase                                                         # type: ignore
 from ae.kivy_relief_canvas import ReliefCanvas                                              # type: ignore
 
 
-__version__ = '0.1.15'
+__version__ = '0.1.16'
 
 
 Builder.load_string("""\
@@ -100,7 +81,6 @@ Builder.load_string("""\
 #: import layout_y ae.gui_help.layout_y
 #: import layout_ps_hints ae.gui_help.layout_ps_hints
 
-
 <HelpBehavior>:
     help_id: ''
     # 'help_layout is not None' is needed because None is not allowed for bool help_lock attribute/property
@@ -108,12 +88,12 @@ Builder.load_string("""\
     help_vars: dict()
     canvas.after:
         Color:
-            rgba: app.font_color[:3] + (0.24 if self.help_lock else 0, )
+            rgba: app.font_color[:3] + (0.24 if self.help_lock and self.width and self.height else 0, )
         Ellipse:
             pos: self.x + sp(9), self.y + sp(9)
             size: self.width - sp(18), self.height - sp(18)
         Color:
-            rgba: app.font_color[:3] + (0.51 if self.help_lock else 0, )
+            rgba: app.font_color[:3] + (0.51 if self.help_lock and self.width and self.height else 0, )
         Line:
             width: sp(3)
             rounded_rectangle: self.x + sp(3), self.y + sp(3), self.width - sp(6), self.height - sp(6), sp(12)
@@ -172,8 +152,6 @@ Builder.load_string("""\
         Ellipse:
             pos: self.pos
             size: self.size
-
-
 """)
 
 
@@ -181,18 +159,18 @@ class HelpBehavior:
     """ behaviour mixin class for widgets having help texts. """
     help_id = StringProperty()      #: unique help id of the widget
     help_lock = BooleanProperty()   #: True if the help mode is active and this widget is not the help target
-    help_vars = DictProperty()      #: dict of extra data for to displayed/render the help text of this widget
+    help_vars = DictProperty()      #: dict of extra data to displayed/render the help text of this widget
 
-    # attributes and methods provided by the class to be mixed into
+    # abstract attributes and methods provided by the class to be mixed into
     collide_point: Callable
 
     def on_touch_down(self, touch: MotionEvent) -> bool:                                    # pragma: no cover
         """ prevent any processing if touch is done on the help activator widget or in active help mode.
 
-        :param touch:   motion/touch event data.
-        :return:        True if event got processed/used.
+        :param touch:           motion/touch event data.
+        :return:                True if event got processed/used.
         """
-        main_app = cast(HelpAppBase, main_app_instance())      # app = App.get_running_app()
+        main_app = App.get_running_app().main_app
 
         if main_app.help_activator.collide_point(*touch.pos):
             return False        # allow help activator button to process this touch down event
@@ -206,7 +184,7 @@ class HelpBehavior:
 
 
 class HelpLayout(ScrollView):                                                           # pragma: no cover
-    """ semi-transparent and click-through container for to display help texts. """
+    """ semi-transparent and click-through container to display help texts. """
     target = ObjectProperty()           #: target widget to display help text for
     ps_hints = ObjectProperty()         #: pos- and size-hints for the layout window widget
     help_text = StringProperty()        #: help text string to display
@@ -214,16 +192,16 @@ class HelpLayout(ScrollView):
     def on_touch_down(self, touch: MotionEvent) -> bool:
         """ check for additional events added by this class.
 
-        :param touch:   motion/touch event data.
-        :return:        True if event got processed/used.
+        :param touch:           motion/touch event data.
+        :return:                True if event got processed/used.
         """
-        return False        # let user click through this transparent help text widget
+        return False            # let user click through this transparent help text widget
 
 
 class HelpToggler(ReliefCanvas, Image):                                                               # pragma: no cover
-    """ widget for to activate and deactivate the help mode.
+    """ widget to activate and deactivate the help mode.
 
-    For to prevent the dismiss of opened popups and dropdowns at help mode activation, this singleton instance has to:
+    To prevent the dismiss of opened popups and dropdowns at help mode activation, this singleton instance has to:
 
     * be registered in its __init__ to the :attr:`~ae.gui_help.HelpAppBase.help_activator` attribute and
     * have a :meth:`~HelpToggler.on_touch_down` method that is eating the activation touch event (returning True) and
@@ -236,7 +214,7 @@ class HelpToggler(ReliefCanvas, Image):
         super().__init__(**kwargs)
 
     def on_touch_down(self, touch: MotionEvent) -> bool:
-        """ touch down event handler for to toggle help mode while preventing dismiss of open dropdowns/popups.
+        """ touch down event handler to toggle help mode while preventing dismiss of open dropdowns/popups.
 
         :param touch:           touch event.
         :return:                True if touch happened on this button (and will get no further processed => eaten).
